@@ -1,4 +1,5 @@
 import abc
+from typing import Any
 from pydantic import BaseModel
 
 class Element(BaseModel):
@@ -21,4 +22,18 @@ class InternalElement(Element, abc.ABC):
         return ""
 
 class ExternalElement(Element):
-    pass
\ No newline at end of file
+    pass
+
+class ShadowElement(Element):
+    pass
+
+def isShadowElement(any_instance: Any) -> bool:
+    """检查实例是否为 Shadow Element
+
+    Args:
+        any_instance (Any): 欲检查的实例
+    
+    Returns:
+        bool: 是否为 Shadow Element
+    """
+    return isinstance(any_instance, ShadowElement)
