@@ -1,4 +1,3 @@
-from __future__ import annotations
 from typing import Optional
 from . import ExternalElement
 
@@ -15,4 +14,13 @@ class FlashImage(Image):
     type = "FlashImage"
 
     def asSerializationString(self) -> str:
-        return f"[mirai:flash:{self.imageId}]"
\ No newline at end of file
+        return f"[mirai:flash:{self.imageId}]"
+
+class Voice(ExternalElement):
+    type = "Voice"
+    voiceId: Optional[str] = None
+    url: Optional[str] = None
+    path: Optional[str] = None
+
+    def asSerializationString(self) -> str:
+        return f"[mirai:voice:{self.voiceId}]"
\ No newline at end of file
